from . import module_b


def func_a():
    module_b.func_b()
    return
